## -*-makefile-*-
##
## $Id: Makefile.m4,v 1.7 1999/11/11 19:01:02 mdw Exp $
##
## Makefile for Catacomb
##
## (c) 1999 Straylight/Edgeware
##

##----- Licensing notice ----------------------------------------------------
##
## This file is part of Catacomb.
##
## Catacomb is free software; you can redistribute it and/or modify
## it under the terms of the GNU Library General Public License as
## published by the Free Software Foundation; either version 2 of the
## License, or (at your option) any later version.
## 
## Catacomb is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU Library General Public License for more details.
## 
## You should have received a copy of the GNU Library General Public
## License along with Catacomb; if not, write to the Free
## Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
## MA 02111-1307, USA.

##----- Revision history ----------------------------------------------------
##
## $Log: Makefile.m4,v $
## Revision 1.7  1999/11/11 19:01:02  mdw
## Use `libtool' to generate a shared library.
##
## Revision 1.7  1999/11/11 19:01:02  mdw
## Use `libtool' to generate a shared library.
##
## Revision 1.6  1999/11/11 17:47:34  mdw
## Updates for new configuration system, and `mptypes' generator.
##
## Revision 1.5  1999/11/11 00:59:17  mdw
## Minor reformatting.
##
## Revision 1.4  1999/10/24 10:20:36  mdw
## Modify for standalone distribution.  The library's getting far too large
## to be sensibly embedded in other programs.
##
## Revision 1.3  1999/10/24 10:04:26  mdw
## Install headers in the right directory.
##
## Revision 1.2  1999/10/23 12:55:35  mdw
## The `CVS' directory can't be hardlinked.  Don't worry about this
## overmuch.
##
## Revision 1.1  1999/09/03 08:41:11  mdw
## Initial import.
##

AUTOMAKE_OPTIONS = foreign

archincludedir = $(libdir)/catacomb/include

## --- List handling macros ---
##
## List handling is nice, usually.  Unfortunately, I based this design on
## TeX list macros rather than anything sensible...

define(`_', `define(`_item', $1)define(`_item_2', $2)emit`'')
define(`adorn', `pushdef(`emit', `$1`'_item`'$3')$2`'popdef(`emit')')
define(`join',
`pushdef(`emit', `adorn(``_(''_item`$2', `$3', ``)'')`'')$1`'popdef(`emit')')
define(`addsuffix', `adorn(`', `$1', `$2')')
define(`lit', `adorn(`', `$1', `')')
define(`nl', `
')

define(`allwithsuffix',
`addsuffix(`$1', `$3') addsuffix(`$2', `$3') dnl
addsuffix(join(`$1', `-', `$2'), `$3')')

## --- Autogenerated source files ---

define(`ciphers', `_(des) _(des3) _(blowfish) _(idea) _(rc5)')
define(`cipher_modes', `_(ecb) _(cbc) _(cfb) _(ofb)')

define(`hashes', `_(md5) _(md4) _(rmd160) _(sha)')
define(`hash_modes', `_(hmac)')

MODES = \
	adorn(`$(srcdir)/', join(`ciphers', `-', `cipher_modes'), `.c') \
	adorn(`$(srcdir)/', join(`ciphers', `-', `cipher_modes'), `.h') \
	adorn(`$(srcdir)/', join(`hashes', `-', `hash_modes'), `.c') \
	adorn(`$(srcdir)/', join(`hashes', `-', `hash_modes'), `.h')

$(MODES): $(srcdir)/genmodes
$(srcdir)/des_sp.h: des-mktab
	./des-mktab >$(srcdir)/des_sp.h

ptab.c ptab.h: genprimes
	./genprimes -h ptab.h -c ptab.c	-m 256 -t "unsigned char" -i ptab

archinclude_HEADERS = mptypes.h

mptypes.h: mptypes
	des_sp.h \
	./mptypes >mptypes.h

BUILT_SOURCES = \
	getdate.c \
	addsuffix(join(`ciphers', `-', `cipher_modes'), `.c') \
	addsuffix(join(`ciphers', `-', `cipher_modes'), `.h') \
	addsuffix(join(`hashes', `-', `hash_modes'), `.c') \
	addsuffix(join(`hashes', `-', `hash_modes'), `.h')

## --- Building the main library ---
libcatacomb_la_LDFLAGS = -version-info 0:3:0
lib_LTLIBRARIES = libcatacomb.la

libcatacomb_la_LDFLAGS = -version-info 0:4:0
## Middle number is the patchlevel.  Final number is the minor version.  The
## difference between the first and last numbers is major version.

define(`emit', `$1.h ')
pkginclude_HEADERS = \
	paranoia.h \
	blkc.h hash.h \
	mpx.h mpw.h mpscan.h mparena.h mp.h mptext.h mpmont.h \
	ptab.h pgen.h rabin.h \
	dsa.h dh.h \
	allwithsuffix(`ciphers', `cipher_modes', `.h') \
	allwithsuffix(`hashes', `hash_modes', `.h')

define(`emit', `$1.c ')
libcatacomb_la_SOURCES = \
	des-base.c des-base.h des_sp.h bf_ikey.h daftstory.h \
	ptab.c pgen.c rabin.c \
	dsa-sign.c dsa-verify.c dsa-gen.c \
	dh-prime.c \
	addsuffix(join(`ciphers', `-', `cipher_modes'), `.c') \
des-base.lo: des_sp.h
mpx.lo: mptypes.h

## --- Utility programs ---
noinst_PROGRAMS = des-mktab mptypes
bin_PROGRAMS = key
bin_SCRIPTS = catacomb-config
noinst_PROGRAMS = des-mktab genprimes mptypes
LDADD = libcatacomb.la

key_SOURCES = keyutil.c getdate.y getdate.h

genprimes_SOURCES = genprimes.c
genprimes_LDADD =

mptypes_SOURCES = mptypes.c
mptypes_LDADD =

## --- Documentation ---

man_MANS = key.1 keyring.5

## --- Other handy definitions ---

EXTRA_DIST = Makefile.m4 genmodes $(man_MANS)

dist-hook:
	@ln getdate.c $(distdir) || ln $(srcdir)/getdate.c $(distdir) || true
	@mkdir $(distdir)/tests
	@ln $(srcdir)/tests/* $(distdir)/tests || true
	@rm -f $(distdir)/tests/*~
TESTS = \
	rc4.t \
	addsuffix(join(`ciphers', `-', `cipher_modes'), `.t') \
	addsuffix(join(`hashes', `-', `hash_modes'), `.t') \
	addsuffix(`ciphers', `.t') addsuffix(`hashes', `.t')
## --- Testing ---

`$1.t: $1.c libcatacomb.la
`define(`testprogs', testprogs \
	$1.t)dnl
$1.t: $1.c libcatacomb.la

adorn(`nl`'CTESTRIG(', `ciphers', `)')
adorn(`nl`'CTESTRIG(', `hashes', `)')
adorn(`nl`'CTESTRIG(', join(`ciphers', `-', `cipher_modes'), `)')
adorn(`nl`'CTESTRIG(', join(`hashes', `-', `hash_modes'), `)')
CTESTRIG(dsa-verify)
CLEANFILES = *.t mptypes.h
TESTS = testprogs

CLEANFILES = *.t mptypes.h des_sp.h ptab.c ptab.h

## --- Makefile building (haha!) ---

$(srcdir)/Makefile.am: $(srcdir)/Makefile.m4
	m4 $(srcdir)/Makefile.m4 >$(srcdir)/Makefile.am
	$(MODES) $(srcdir)/des_sp.h \
	$(srcdir)/getdate.c getdate.c
	$(srcdir)/Makefile.am \
	$(srcdir)/getdate.c getdate.c \
	$(MODES)

##----- That's all, folks ---------------------------------------------------
