/* -*-c-*-
 *
 * $Id: mpscan.c,v 1.1 1999/09/03 08:41:12 mdw Exp $
 *
 * Sequential bit scan of multiprecision integers
 *
 * (c) 1999 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of Catacomb.
 *
 * Catacomb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * Catacomb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with Catacomb; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

/*----- Revision history --------------------------------------------------* 
 *
 * $Log: mpscan.c,v $
 * Revision 1.1  1999/09/03 08:41:12  mdw
 * Initial import.
 *
 */

/*----- Header files ------------------------------------------------------*/

/*----- Data structures ---------------------------------------------------*/

/*----- Static variables --------------------------------------------------*/

/*----- Main code ---------------------------------------------------------*/

/* --- @mpscan_initx@ --- *
 *
 * Arguments:	@mpscan *m@ = pointer to bitscanner structure
 *		@const mpw *v@ = vector of words to scan
 *		@size_t len@ = length of vector in words
 *
 * Returns:	---
 *
 * Use:		Initializes a bitscanner from a low-level vector-and-length
 *		representation of an integer.  Initially no bit is ready; you
 *		must call @mpscan_step@ before anything useful will come
 *		out.
 */

void mpscan_initx(mpscan *m, const mpw *v, size_t len)
{
  MPSCAN_INITX(m, v, len);
}

/* --- @mpscan_step@ --- *
 *
 * Arguments:	@mpscan *m@ = pointer to bitscanner
 *
 * Returns:	Nonzero if there is another bit to read.
 *
 * Use:		Steps on to the next bit in the integer.  The macro version
 *		evaluates its argument multiple times.
 */

int mpscan_step(mpscan *m) { return (MPSCAN_STEP(m)); }

/* --- @mpscan_bit@ --- *
 *
 * Arguments:	@const mpscan *m@ = pointer to bitscanner
 *
 * Returns:	The value of the current bit.
 *
 * Use:		Reads the value of the current bit looked at by a
 *		bitscanner.
 */

int mpscan_bit(const mpscan *m) { return (MPSCAN_BIT(m)); }

/*----- That's all, folks -------------------------------------------------*/
